@@ -16,6 +16,7 @@ BEGIN { $fields = {
 	"subject_id" => new WWW::Shopify::Field::Int(),
 	"subject_params" => new WWW::Shopify::Field::String(),
 	"title" => new WWW::Shopify::Field::String(),
+	"link_list_id" => new WWW::Shopify::Field::Relation::Parent(),
 	"link_type" => new WWW::Shopify::Field::String::Enum(["collection", "product", "frontpage", "catalog", "page", "blog", "search", "http"])
 }; }
 
@@ -28,6 +29,19 @@ sub link_model_type {
 	return 'WWW::Shopify::Model::Product' if $_[0]->link_type eq 'product';
 	return 'WWW::Shopify::Model::Page' if $_[0]->link_type eq 'page';
 	return 'WWW::Shopify::Model::Blog' if $_[0]->link_type eq 'blog';
+	return () if wantarray;
+	return undef;
+}
+
+sub link_url {
+	return '/search' if $_[0]->link_type eq "search";
+	return '/' if $_[0]->link_type eq "frontpage";
+	return '/collections/all' if $_[0]->link_type eq "catalog";
+	return $_[0]->subject if $_[0]->link_type eq "http";
+	return '/collections/' . $_[0]->subject if $_[0]->link_type eq 'collection';
+	return '/products/' . $_[0]->subject if $_[0]->link_type eq 'product';
+	return '/pages/' . $_[0]->subject if $_[0]->link_type eq 'page'; 
+	return '/blogs/' . $_[0]->subject if $_[0]->link_type eq 'blogs';
 	return undef;
 }
 
